function [w, t] = LL_wake(r, N, theta, y_wake, z_wake, w_s, y_centre, z_centre, C_B, C_WA, D)
% This function finds the wake fraction of each radial position of the 
% lifting line. Then the corresponding thrust deduction fractions are 
% calculated based on an empirical relation

% Horizontal and vertical coordinates of lifting line
y_n = y_centre + r.*cos(theta);
z_n = z_centre + r.*sin(theta);

% Creating vectors of the coordinates of the given wake data
y_wake_vector = y_wake(1,:);
z_wake_vector = transpose(z_wake(:,1));

% Preallocation of indices
index_wake_y = zeros(1, N);
index_wake_z = zeros(1, N);

% Calculating the index of the y-coordinate of the lifting line wrt the 
% given wake data
for i = 1:N
    for j = 1:length(y_wake_vector)
        
        if round(y_n(i), 1) == round(y_wake_vector(j), 1)
            index_wake_y(i) = j;
        end
    end
end

% Calculating the index of the z-coordinate of the lifting line wrt the 
% given wake data
for i = 1:N
    for j = 1:length(z_wake_vector)
        
        if round(z_n(i), 1) == round(z_wake_vector(j), 1)
            index_wake_z(i) = j;
        end
    end
end

% Preallocation of the corresponding wake fractions
w = zeros(1, N);

% Calculating the wake fractions corresponding to the y and z coordinates
% of the lifting line
for i = 1:N
    w(i) = w_s(index_wake_z(i), index_wake_y(i));
end

% Thrust deduction factor according to empirical equation in 
% Naval Hydrodynamics Foil and Propeller Theory compendium by Sverre Steen, 
% page 133
t_w = 1.57 - 2.3*(C_B/C_WA) + 1.5*C_B;
t = t_w*w;  

end

