function [cav_points] = cav_check(r, y, V_inf, rho_s, g, pa, pv, h, alpha_e, r_R_interp, prop_num)
% This function finds the number of cavitating points on each propeller.
% The below plot should be commented when complete optimization is
% conducted to avoid plotting for all iterations. 

% Xfoil is used to find the minimum pressure coefficient of each blade
% section. Then the effective angle of attack og each foil section are
% required as input. 9 sections are evaluated. Results are then
% interpolated to all foil sections. Minimum pressure coefficient at blade
% tip is extrapolated

% Defining corresponding alpha_e values to the r_R_interp vector
alpha_e_interp = interp1(y, alpha_e, r_R_interp);

% Finding negative pressure coefficent from Xfoil
[C_p] = xfoil_cav(r_R_interp, alpha_e_interp, y);
C_p_neg = -C_p;

% Cavitation number
sigma = (pa-pv+rho_s.*g.*(h-r))./(0.5.*rho_s.*(V_inf.^2));

% Preallocation
cav = zeros(1,length(r));

% Checking if the sections are cavitating. The variable 'cav' is equal to 1
% if cavitation occurs and zero if not
for i=1:length(r)
    
    if C_p_neg(i) > sigma(i)
       cav(i) = 1;
    else
       cav(i) = 0;
    end
end

% Summing up all cavitating foil sections
cav_points = numel(find(cav==1));

% Cavitation plot
cav=figure;
plot(y, C_p_neg);
hold on
plot(y, sigma);
legend('-C_p,min','\sigma')
xlabel('r/R')
ylabel('-C_p,min, \sigma')
title(['Propeller number ' num2str(prop_num)]);
set(cav,'Units','Inches');
pos = get(cav,'Position');
set(cav,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])

end