function [I_A, I_T] = induction_factors(y, Z, beta_i)
% This function calculates the induction factors according to van Oossanen
% page 22

% Preallocation
p = zeros(length(y), length(y));
term = zeros(length(y), length(y));
u = zeros(length(y), length(y));
g = zeros(length(y), length(y));
f = zeros(length(y), length(y));
A = zeros(length(y), length(y));
B = zeros(length(y), length(y));
I_A = zeros(length(y), length(y));
I_T = zeros(length(y), length(y));

for n = 1:length(y)
    for i = 1:length(y)
        p(n,i) = 1 + (((y(n)/y(i))^2)/(tan(beta_i(i))^2));
        
        term(n,i) = (sqrt(p(n,i))-1)*(((1/(sin(beta_i(i))))-1)^(-1))*(y(i)/y(n));
        u(n,i) = exp(Z*log(term(n,i)) + sqrt(p(n,i)) - (1/(sin(beta_i(i)))));
        
        g(n,i) = (sin(beta_i(i))^3)*(2+ (9/(tan(beta_i(i))^2))) + (3*p(n,i)-5)*p(n,i)^(-3/2);
        
        f(n,i) = (p(n,i)^(-0.25))*sin(beta_i(i))^(-0.5);
        
        if  y(n)/y(i) > 1
            A(n,i) = f(n,i)*((1/(u(n,i)-1)) - (1/(24*Z))*g(n,i)*log(abs(u(n,i)/(u(n,i)-1))));
            I_A(n,i) = ((y(n)/y(i))-1)*((Z*A(n,i))/(tan(beta_i(i))));
            I_T(n,i) = (1-(y(i)/y(n)))*Z*(1+A(n,i));
        elseif y(n)/y(i) == 1
            I_A(n,i) = cos(beta_i(i));
            I_T(n,i) = sin(beta_i(i));
        else
            B(n,i) = f(n,i)*((u(n,i)/(1-u(n,i))) + (1/(24*Z))*g(n,i)*log(abs(1/(1-u(n,i)))));
            I_A(n,i) = (1-(y(n)/y(i)))*(Z/(tan(beta_i(i))))*(1+B(n,i));
            I_T(n,i) = ((y(i)/y(n))-1)*Z*B(n,i);
        end
        
    end
end

end