function [tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp, PD_07] = wag_geo(D, Z, y, r, AEA0, fi_07, r_07)
% In this function, the geometrical properties of the Wageningen B series
% are calculated. Subscript interp indicates shorter vectors that are to be
% used in Xfoil. They corresponds to r_R_interp which is radial position on
% the blade from hub to tip, with length 9. 

if Z==3
    % Table 1 page 4 Oosterveld & Oossanen
    r_R_interp = [0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1];
    cr_D_Z_AEA0 = [1.663 1.832 2.000 2.120 2.186 2.186 2.127 1.657 0];
    br_cr = [0.350 0.350 0.350 0.355 0.389 0.442 0.478 0.500 0.000];
    Ar = [0.0526 0.0464 0.0402 0.0340 0.0278 0.0216 0.0154 0.0092 0.0030];
    Br = [0.0040 0.0035 0.0030 0.0025 0.0020 0.0015 0.0010 0.0002 0.0000];
    
else
    % Table 1 page 4 Oosterveld & Oossanen
    r_R_interp = [0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1];
    cr_D_Z_AEA0 = [1.662 1.882 2.050 2.152 2.187 2.144 1.970 1.582 0];
    br_cr = [0.350 0.350 0.351 0.355 0.389 0.443 0.479 0.5 0];
    Ar = [0.0526 0.0464 0.0402 0.0340 0.0278 0.0216 0.0154 0.0092 0.0030];
    Br = [0.004 0.0035 0.0030 0.0025 0.002 0.0015 0.001 0.0005 0];
end

% Max section thickness
tm_interp = (Ar-(Br.*Z)).*D;
tm = interp1(r_R_interp, tm_interp, y, 'pchip');

% Radial chord length
c_interp = (AEA0/Z).*D.*cr_D_Z_AEA0;
c = interp1(r_R_interp, c_interp, y, 'pchip');

% Chord-wise length from leading edge to position of maximum thickness
b_interp = br_cr.*c_interp;

% Pitch distribution
PD_07 = (tan(fi_07)*2*pi*r_07)/D;
P_table = [0.822 0.887 0.95 0.992 1 1 1 1 1].*PD_07.*D;
pitch = interp1(r_R_interp, P_table, y, 'pchip');
fi = atan(pitch./(2.*pi.*r));

end
