function particle_point = wag_openwater(x_0)
% This is the obJ_0ective function of the particle swarm algorithm that finds
% the initial values of the propeller geometry. Note that number of blades
% has to be manually adJ_0usted in this function

% Defining the variables 
AEA0 = x_0(1);
J_0 = x_0(2);
PD_07 = x_0(3);

% Defining number of blades
Z = 4;

% Wageningen open water diagram
% KQ
filename = 'KQ.csv';
KQ_mat = csvread(filename,1,0);
B_abcd = transpose(KQ_mat(:,1));
a_kq = transpose(KQ_mat(:,2));
b_kq = transpose(KQ_mat(:,3));
c_kq = transpose(KQ_mat(:,4));
d_kq = transpose(KQ_mat(:,5));

% KT
filename = 'KT.csv';
KT_mat = csvread(filename,1,0);
A_abcd = transpose(KT_mat(:,1));
a_kt = transpose(KT_mat(:,2));
b_kt = transpose(KT_mat(:,3));
c_kt = transpose(KT_mat(:,4));
d_kt = transpose(KT_mat(:,5));

% Preallocation
KT = zeros(length(PD_07), length(J_0));
KQ = zeros(length(PD_07), length(J_0));

%Calculating KT and KQ 
for p = 1:length(PD_07)
    for i = 1:length(J_0)
        KT(p,i) = sum(A_abcd.*(J_0(i).^a_kt).*(PD_07(p).^b_kt).*(AEA0.^c_kt).*(Z.^d_kt));
        KQ(p,i) = sum(B_abcd.*(J_0(i).^a_kq).*(PD_07(p).^b_kq).*(AEA0.^c_kq).*(Z.^d_kq));
     
        % Negative KT are outside the range of the Wageningen B 
        % experimental results, correcting this by setting KT = NaN where KT
        % is negative
        if KT(p,i) < 0
            KT(p,i) = NaN;
        else
            KT(p,i) = KT(p,i);
        end
        
        if KQ(p,i) < 0
            KQ(p,i) = NaN;
        else
            KQ(p,i) = KQ(p,i);
        end
    end
end

%Open water efficiency
eta_0 = (KT.*J_0)./(2.*pi.*KQ);

particle_point = -eta_0;

end