function [w_s, y_wake, z_wake] = wake(V_m, BWL_m, scale)
% This function imports the wake fractions from .csv-file provided by 
% co-supervisor. The wake fractions are assumed to be unscaled

% Importing from .csv file
filename = 'wakeDataDTC.csv';
wake_mat = csvread(filename,1,2);
Y_m = round(wake_mat(:,5), 4);
Z_m = round(wake_mat(:,6), 4);
u_m = wake_mat(:,1);

% Wake fraction
w_m_exc = 1 - u_m/V_m;

% Deleting all values corresponding to z>0 (above waterline)
index_z = find(Z_m <= 0);

% Mirroring of data
Y_mirror = vertcat(Y_m(index_z), -Y_m(index_z));
Z_mirror = vertcat(Z_m(index_z), Z_m(index_z));
w_mirror = vertcat(w_m_exc(index_z), w_m_exc(index_z)); 

% 3D interpolation of data
[y_wake, z_wake] = meshgrid(-BWL_m/2:.001:BWL_m/2, -0.4:.001:max(Z_mirror));
w_interp = griddata(Y_mirror, Z_mirror, w_mirror, y_wake, z_wake);

% Scaling coordinates to full-scale
y_wake = y_wake.*scale; 
z_wake = z_wake.*scale;

% Model and full scale wake
w_m = w_interp;

% Assuming the wake is unscaled
w_s = w_m;           

end
              

