function [T, P, cav_points, eta_H, beta_i_07] = analysis(y_centre, z_centre, r, N, theta, y_wake, z_wake, w_s, C_B, C_WA, D, R, dr, y, tm, c, fi, n_rev, V_s, R_boss, Z, rho_s, g, pa, pv, nu_s, h, C_Lc_wag, r_R_interp, fi_07, prop_num)
% This  function analysis the performance for each angular position of the
% propeller blade for a propeller with centre coordinates 
%(y_centre, z_centre), located in a grid

% Preallocation
w = zeros(length(theta), N);
t = zeros(length(theta), N);
V_inf = zeros(length(theta), N);
alpha_e = zeros(length(theta), N);
beta_i_07 = zeros(1, 1);
T = zeros(length(theta), 1);
P = zeros(length(theta), 1);
eta_H = zeros(length(theta), 1);
cav_points = zeros(1, 1);

% Analyzing each angular position of the propeller blade
for i = 1:length(theta)
    % Finding the wake fractions of the N stations of the lifting line for 
    % each angular position of the blade
    [w(i,:), t(i,:)] = LL_wake(r, N, theta(i), y_wake, z_wake, w_s, y_centre, z_centre, C_B, C_WA, D);
    
    % Lifting line calculations
    [T(i), P(i), V_inf(i,:), alpha_e(i,:), beta_i_07(i)] = LL_iter(N, R, dr, r, y, tm, c, fi, n_rev, V_s, R_boss, Z, rho_s, C_Lc_wag, nu_s, w(i,:), D);
    
    % ''Hull efficiency''
    % The wake is already included in LL_iter so the hull efficiency only
    % depends on the thrust deduction factor
    index_07 = find(round(y,1) == 0.7, 1, 'first');
    eta_H(i) = 1-t(i,index_07);
    
    % Checking the blade in top position for cavitation
    if i == 1
        [cav_points(i)] = cav_check(r, y, V_inf(i,:), rho_s, g, pa, pv, h, alpha_e(i,:), r_R_interp, prop_num);
    else
        continue
    end
    
end

% The pitch are to be adjusted such that the outermost foil section on the
% blade has sufficiently low effective angle of attack. Index 1 corresponds
% to angular blade position 12 o'clock.
beta_i_07 = beta_i_07(1);

end

