function [D,h, y_centre, z_centre] = diameter_calc(row, col, BWL_m, scale)
% This function calculates the maximum possible diameter of the propeller
% configurations and the centre coordinates of the propellers

% Height of grid (model scale)
%Z_max an Z_min for original propeller 
Z_max = -0.03;              
Z_min = -0.09;               
Z_lim = Z_max - Z_min;

% Width of grid (model scale)
Y_lim = BWL_m;

% Origo of global coordinate system
origo = [Y_lim/2, 0];

% Safety factor to make space between propellers
safety = 0.1;

% Defining the diameter, D
D_y = Y_lim/(col+(col-1)*safety);
D_z = Z_lim/(row+(row-1)*safety);
D_m = min(D_y, D_z);
D_s = D_m*scale;

% Using a local coordinate system with origin in the top left corner of the
% grid
y_local = NaN(1, col);
z_local = NaN(row, 1);

% Defining the centre coordinates of the propellers
 for i = 1:row  
    for j = 1:col
        y_local(j) = 0.5*D_y+(j-1)*(D_y+safety*D_y);  
        z_local(i) = -Z_max + 0.5*D_z+(i-1)*(D_z+safety*D_z);
    end
 end
    
% Converting centre coordinates from local to global coordinates
y_centre = repmat((y_local - origo(1)), [row, 1]);
z_centre = repmat(-z_local, [1, col]);

% Converting from model scale to full-scale
D = D_s;
y_centre = y_centre.*scale;
z_centre = z_centre.*scale;

% Submergence
h = -Z_max*scale+(D/2);

end

