% Preparation
clc
clear all
close all

%% Calculating initial values from Wageningnen B open water data
% Using particle swarm optimization to find the initial values to be
% used in the interior-point algorithm

% Objective function
objf_init = @wag_openwater;

% Number of variables
nvar_init = 3;

% Defining lower and upper limits of the design variables according to
% the Wageningen B series
lb_init = [0.3 0.4 0.5];
ub_init = [1.05 2 1.4];

% Options for the particle swarm optimization
options = optimoptions('particleswarm', 'SwarmSize', 100, 'MaxIterations',...
    50, 'PlotFcn', @pswplotbestf);

% Particle swarm optimization to find initial values
[x_0, eta_0_init] = particleswarm(objf_init, nvar_init, lb_init, ub_init, options);

% Collecting initial values in a vector where x_0(2) is added in
% accordance with the number of propellers that are to be optimized
x_0 = [x_0(1), x_0(2), x_0(2), x_0(2), x_0(2), x_0(2)];

%% Using interior-point optimization to find the optimal propeller design
% A quadratic penalty function is used to ensure that the thrust is within
% 3% of required thrust using the quadratic penalty method

% The required thrust from the propulsion system is
T_req = 1453300;

% First values of total thrust (T_tot), iteration number (iter) and
% quadratic penalty (penalty_thr)
T_tot = 1;
iter = 1;
penalty_thr = 0.02;

% Max number of iterations
iter_max = 50;

while ((0.97 > T_tot/T_req) || (T_tot/T_req > 1.03)) && iter<=iter_max
    
    % Nested function that contains the objective function and optimization
    % algorithm
    [x, fval] = runnested(x_0, T_req, penalty_thr);
    
    % Calculating the total thrust from the optimal values
    [T_tot, eta, cav_tot, row, col, Z, D, theta, P_tot, PD_07] = main_no_opt(x);
    
    % Updating values to be used for input in the next iteration
    x_0 = x;
    penalty_thr = penalty_thr*15;
    
    disp('Nested number')
    disp(iter)
    
    iter = iter+1;
    
end

% Preparation for output text file
AEA0 = x(1);
J_0 = x(2:length(x));

% Writing output text file
output;


