function [C_p] = xfoil_cav(r_R_interp, alpha_e_interp, y)
% This function calculates the minimum pressure coefficients of the blade
% sections in the r_R_interp vector, except for the outermost section. The
% pressure coefficients are calculated in Xfoil. Input commands are written
% in this function to text files. Results are imported and processed from text files

% NOTE: This script contains two commands where file paths have to be
% defined. These must be specified before running the optimization.

% NOTE2: The program Xfoil should be in the same folder as this
% script

% NOTE3: An empty text file called xfoilCMD_cav.txt should be placed 
% in the same folder as this function, prior to the analysis is initiated

% NOTE4: As this script enters the operating system of the computer, 
% the codes  depends on which operating system that is used. This script 
% is for Windows. If Mac is used, use system instead of dos and 
% \r\n for space when writing to text files

fclose('all');

% Deleting previous files
for i = 1:length(r_R_interp)-1
    delete([num2str(i) '.txt'])
end

% Creating a text file and importing it to Xfoil for each foil section
for i = 1:length(r_R_interp)-1
    
    % Opening the text file with commands that are going to be ran in Xfoil
    fid = fopen('xfoilCMD_cav.txt', 'w');
    
    % Writing commands into the file. \n is indicating new line
    % Loading the text file with the foil coordinates
    fprintf(fid,'%s','load');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s',['G:\Master_T/xFoil_' num2str(i) '.txt']);
    fprintf(fid,'\r\n');
    
    % Defining a name of the foil
    fprintf(fid,'%s',['wag' num2str(i)]);
    fprintf(fid,'\r\n');
    
    % Discretizing of foil sections
    fprintf(fid,'%s','gdes');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','cadd');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','1');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','1');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','ppar');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','N');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','300');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\r\n');
    
    % Empty space (enter)
    fprintf(fid,'%s','');
    fprintf(fid,'\r\n');
    
    % Going into the oper menu
    fprintf(fid,'%s','oper');
    fprintf(fid,'\r\n');
    
    % Defining angle of attack of the foil section
    fprintf(fid,'%s','alfa');
    fprintf(fid,'\r\n');
    fprintf(fid,'%s', num2str(alpha_e_interp(i)*(180/pi)));
    fprintf(fid,'\r\n');
    
    % Writing Cp to file
    fprintf(fid,'%s','cpwr');
    fprintf(fid,'%s',['G:\Master_T/xFoil_' num2str(i) '.txt']);
    fprintf(fid,'\r\n');
   
    % Empty space
    fprintf(fid,'%s','');
    fprintf(fid,'\r\n');
    
    % Quit
    fprintf(fid,'%s','quit');
    
    % Closing the file id
    fclose(fid);
   
    % Running Xfoil
    dos('xfoil.exe < xfoilCMD_cav.txt')
    %system('Xfoil.app/Contents/Resources/xfoil < xfoilCMD_cav.txt');
    
end

% Processing the desired data
% Finding minimum pressure coefficient
 C_p = zeros(1, length(r_R_interp)-1);

for i = 1:length(r_R_interp)-1
    fname = [num2str(i) '.txt'];
    x_C_p = importdata(fname);
    C_pp = str2double(x_C_p.textdata((4:303),3));
    C_p(i) = min(C_pp);
end

C_p = interp1(r_R_interp(1:(length(r_R_interp)-1)), C_p, y, 'pchip', 'extrap');

end

