% Preparation
clc
clear all
close all

% Importing input data
input;

% Defining number of spanwise stations
N = 30;

% Defining radial variables 
R      = D/2;
R_boss = R/5;                             
dr     = (R-R_boss)/N;
r      = linspace(R_boss, R, N);
y      = r./R;
y_boss = R_boss/R;                            

% Importing the Wageningen open water diagram to be used for validation
[KT, KQ, J, eta_0] = wag_openwater(PD_07, AEA0, Z);

% Importing geometry
[tm, c, fi, tm_interp, c_interp, b_interp, r_R_interp] = wag_geo(D, Z, y, r, AEA0, PD_07);

% Running Xfoil to determine camber lift coefficient
[C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp);

% Defining rate of revolutions
J_val = J(12:1:40);
n_rev = V_s./(J_val.*D);

% Preallocation
eta_0_val = zeros(1, length(J_val));
KT_val = zeros(1, length(J_val));  
KQ_val = zeros(1, length(J_val));
U_A = zeros(length(J_val), N);
U_T = zeros(length(J_val), N);

% Analyzing for all advance numbers
for i = 1:length(J_val)
    
% Lifting line calculations 
[eta_0_val(i), KT_val(i), KQ_val(i)] = LL_iter(N, R, dr, r, y, tm, c, fi, n_rev(i), V_s, R_boss, Z, rho_s, D, C_Lc_wag, Re_wag, nu_s);

end

%% The difference in open water efficiency between the plynomials and lifting line results  
%The difference in open water efficiency
diff_eta = max(eta_0)-max(eta_0_val);

% The fraction of the deviation with respect to lifting line results
diff_eta_ratio = diff_eta/max(eta_0_val);

%% Validation plot
% Open water diagram
ow=figure;
plot(J, eta_0);
hold on
plot(J_val, eta_0_val, '-o');
hold on
plot(J, KT);
hold on
plot(J_val, KT_val, '-o');
hold on
plot(J, 10.*KQ);
hold on
plot(J_val, 10.*KQ_val, '-o');
axis equal
grid minor
xlabel('Advance number, J_0')
ylabel('K_T, K_Q, \eta_0')
title('Open water diagram AE/A0=0.55, Z=4, P/D=0.6')
legend('\eta_0','\eta_0_v','K_T', 'K_T_v', '10*K_Q', '10*K_Q_v')
set(ow,'Units','Inches');
pos = get(ow,'Position');
set(ow,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])



