function[KT, KQ, J, eta_0] = wag_openwater(PD_07, AEA0, Z)
% This function calculates open water performance based on polynomials.
% Polynomial coefficients are imported from .csv files

% KQ coefficients
filename = 'KQ.csv';
KQ_mat = csvread(filename,1,0);
B_abcd = transpose(KQ_mat(:,1));
a_kq = transpose(KQ_mat(:,2));
b_kq = transpose(KQ_mat(:,3));
c_kq = transpose(KQ_mat(:,4));
d_kq = transpose(KQ_mat(:,5));

% KT coefficients
filename = 'KT.csv';
KT_mat = csvread(filename,1,0);
A_abcd = transpose(KT_mat(:,1));
a_kt = transpose(KT_mat(:,2));
b_kt = transpose(KT_mat(:,3));
c_kt = transpose(KT_mat(:,4));
d_kt = transpose(KT_mat(:,5));

% Advance numbers, J, are defined in a vector
J = linspace(0, 1.7, 100);

% Preallocation
KT = zeros(length(PD_07), length(J));
KQ = zeros(length(PD_07), length(J));

%Calculating KT and KQ
for p = 1:length(PD_07)
    for i = 1:length(J)
        KT(p,i) = sum(A_abcd.*(J(i).^a_kt).*(PD_07(p).^b_kt).*(AEA0.^c_kt).*(Z.^d_kt));
        KQ(p,i) = sum(B_abcd.*(J(i).^a_kq).*(PD_07(p).^b_kq).*(AEA0.^c_kq).*(Z.^d_kq));
     
        % Negative KT are outside the range of the Wageningen B 
        % experimental results, correcting this by setting KT = NaN where KT
        % is negative
        if KT(p,i) < 0
            KT(p,i) = NaN;
        else
            KT(p,i) = KT(p,i);
        end
        
        if KQ(p,i) < 0
            KQ(p,i) = NaN;
        else
            KQ(p,i) = KQ(p,i);
        end
    end
end

%Open water efficiency
eta_0 = (KT.*J)./(2.*pi.*KQ);

end