function [C_Lc_wag] = xfoil(b_interp, tm_interp, c_interp, r_R_interp)
% This function calculates the lift coefficient due to camber. Based in the
% geometrical properties subscripted with interp, the boordinates of the
% corresponding blade sections are calculated and imported into Xfoil.
% In Xfoil, their lift coefficients due to camber are calculated and
% interpolated to all N radial positions

% NOTE: This script contains one command where file paths have to be
% defined. These must be specified before running the optimization.

% NOTE2: The program Xfoil should be in the same folder as this
% script

% NOTE3: An empty text file called xfoilCMD.txt should be placed 
% in the same folder as this function, prior to the analysis is initiated

% NOTE4: As this script enters the operating system of the computer, 
% the codes  depends on which operating system that is used. This script 
% is for Mac. If Windows is used, use dos instead of system and 
% \r\n for space when writing to text files

fclose('all');

% Deleting previous files
for i = 1:length(r_R_interp)-1
    delete(['xfoil_' num2str(i) 'cl.txt'])
end

% Creating a text file and importing it to Xfoil for each foil section. The
% outermost section is not included, as it is assumed to be small enough
% for its camber lift coefficient to be zero
for i = 1:length(r_R_interp)-1
    
    % Defining an index variable that is needed for the foil_coord function
    index_r_R = i;
    
    % Importing the coordinates of the foil section
    [coord] = foil_coord(b_interp, tm_interp, c_interp, index_r_R, r_R_interp);
    
    % Defining the coordinates that are going to be put into the 
    % input text file for Xfoil
    outputText = transpose(coord);
    
    % Defining the name and format of file
    fname = ['xFoil_' num2str(i) '.txt'];
    
    % Opening the file in order to start writing
    fileID = fopen(fname,'w');
    
    % Writing the foil coordinates into the created text file
    fprintf(fileID, '%8.4f %12.4f\r\n', outputText);
    
    % Closing the file id
    fclose(fileID);
    
    %The input text file for Xfoil is now completed
    
    % Opening the text file with commands that are going to be ran in Xfoil
    fid = fopen('xfoilCMD.txt', 'w');
    
    % Writing commands into the file. \n is indicating new line
    % Loading the text file with the foil coordinates
    fprintf(fid,'%s','load');
    fprintf(fid,'\n');
    fprintf(fid,'%s',['/Users/vildenylund/Desktop/FINAL/Validation_codes/xFoil_' num2str(i) '.txt']);
    fprintf(fid,'\n');
    
    % Defining a name of the foil
    fprintf(fid,'%s',['wag' num2str(i)]);
    fprintf(fid,'\n');
    
    % Discretization of foil sections
    fprintf(fid,'%s','gdes');
    fprintf(fid,'\n');
    fprintf(fid,'%s','cadd');
    fprintf(fid,'\n');
    fprintf(fid,'%s','1');
    fprintf(fid,'\n');
    fprintf(fid,'%s','1');
    fprintf(fid,'\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\n');
    fprintf(fid,'%s','ppar');
    fprintf(fid,'\n');
    fprintf(fid,'%s','N');
    fprintf(fid,'\n');
    fprintf(fid,'%s','300');
    fprintf(fid,'\n');
    fprintf(fid,'%s','');
    fprintf(fid,'\n');
    
    % Empty space (enter)
    fprintf(fid,'%s','');
    fprintf(fid,'\n');
    
    % Going into the oper menu
    fprintf(fid,'%s','oper');
    fprintf(fid,'\n');
    
    % Claiming the polar data for the foil
    fprintf(fid,'%s','pacc');
    fprintf(fid,'\n');
    
    % Creating a file for the polar data
    fprintf(fid,['xfoil_' num2str(i) 'cl.txt']);
    fprintf(fid,'\n');
    
    % Creating a dump file for the polar data
    fprintf(fid,'%s',['xfoil_' num2str(i) 'dump.txt']);
    fprintf(fid,'\n');
    
    % Defining angle of attack of the foil section
    fprintf(fid,'%s','alfa');
    fprintf(fid,'\n');
    fprintf(fid,'%s','0');
    fprintf(fid,'\n');
    
    % Empty space
    fprintf(fid,'%s','');
    fprintf(fid,'\n');
    
    % Quit
    fprintf(fid,'%s','quit');
    
    % Closing the file id
    fclose(fid);
   
    % Running Xfoil
    system('Xfoil.app/Contents/Resources/xfoil < xfoilCMD.txt');
    
end

% Deleting unnecessary data
for i = 1:length(r_R_interp)-1
    delete(['xfoil_' num2str(i) 'dump.txt']);
end

C_Lc_wag = zeros(1, length(r_R_interp));

% Processing the desired data
for i = 1:length(r_R_interp)-1
    fname = ['xfoil_' num2str(i) 'cl.txt'];
    fid = fopen(fname, 'r');
    temp1 = textscan(fid,'%s');
    temp2 = temp1{1};
    
    size = length(temp2(:,1));
    
    if size < 48 
    temp2{48,1} = '0';
    end
    
    C_Lc_wag(i) = str2num(temp2{48});
    fclose(fid);
end

end